@@ -83,6 +83,7 @@
                udecl->mdecl split-udecl
                declr-ident declr-name
                clean-field-list clean-fields)
+  #:use-module (ice-9 match)
   #:use-module ((srfi srfi-1) #:select (fold fold-right remove))
   #:use-module (srfi srfi-11)           ; let-values
   #:use-module ((sxml fold) #:select (foldts foldts*))
@@ -96,14 +97,7 @@
   ;; debugging:
   #:use-module (system vm trace)
   #:use-module (ice-9 pretty-print))
-(cond-expand
- (mes
-  (use-modules (nyacc lang c99 cppmach))
-  (use-modules (smatch))
-  (define-macro (match exp . clauses)
-    `((smatch-lambda . ,clauses) ,exp)))
- (else
-  (use-modules (ice-9 match))))
+;; undocumented Guile builtins: or-map
 
 (define (sferr fmt . args) (apply simple-format (current-error-port) fmt args))
 (define (pperr exp)
@@ -863,7 +857,7 @@
       (`((struct-def . ,rest)) (make-udecl (car mdecl-tail) declr))
       (`((union-def . ,rest)) (make-udecl (car mdecl-tail) declr))
       (`((enum-def . ,rest))  (make-udecl (car mdecl-tail) declr))
-      (_ (sferr "munge/mdecl->udecl missed:\n")
+      (__ (sferr "munge/mdecl->udecl missed:\n")
           (pperr mdecl-tail)
           (throw 'nyacc-error "munge/mdecl->udecl failed"))))
 
