@@ -105,7 +105,7 @@
   (cond
    (CC CC)
    ((getenv "CC") => identity)
-   (else "gcc")))
+   (else "gcc -std=gnu99")))
 
 ;; @deffn {Procedure} convert-def line
 ;; Convert string in gcc cpp defs to pair of strings for term and replacement.
@@ -131,7 +131,7 @@
 ;; @deffn {Procedure} get-sys-cpp-defs [args] [#:CC "gcc"] => '("ABC=123" ...)
 ;; Generate a list of default defines produced by gcc (or other comiler).
 ;; If keyword arg @arg{CC} is not provided this procedure looks for environment
-;; variable @code{"CC"}, else it defaults to @code{"gcc"}.
+;; variable @code{"CC"}, else it defaults to @code{"gcc -std=gnu99"}.
 ;; @end deffn
 (define* (get-sys-cpp-defs #:optional (args '()) #:key CC)
   ;; @code{"gcc -dM -E"} will generate lines like @code{"#define ABC 123"}.
@@ -274,7 +274,13 @@
       ((type-name (decl-spec-list (type-spec ,spec))) (spec->str spec))
       ((fixed-type ,name) name)
       ((float-type ,name) name)
-      (,_ (sferr "c99/util: missed ~S\n" spec) "MISSED")))
+      ;;((mul ,lt ,rt) (c99
+      (,_ (let* ((sp (source-properties spec))
+                 (fn (assq-ref sp 'filename))
+                 (ln (assq-ref sp 'line))
+                 (wm "warning: c99 attribute not processed"))
+            (if sp (sferr "~a at ~a:~a\n" wm fn ln) (sferr "~a: ~s\n" wm spec))
+            "MISSED"))))
   (if (null? attr-list) '()
       `(attributes ,(string-join (map spec->str (sx-tail attr-list)) ";"))))
 
@@ -354,19 +360,16 @@
 ;; @deffn {Procedure} remove-comments sx0 => sx1
 ;; Remove comments from the parse tree @var{sx0} generated by @code{parse-c99}.
 ;; @end deffn
-(define (remove-comments sx0)
-  (if(not (pair? sx0)) sx0
-     (cons (car sx0)
-           (let loop ((tail (cdr sx0)))
-             (cond
-              ((null? tail)
-               '())
-              ((not (pair? (car tail)))
-               (cons (car tail) (remove-comments (cdr tail))))
-              ((eq? 'comment (caar tail))
-               (loop (cdr tail)))
-              (else
-               (cons (remove-comments (car tail)) (loop (cdr tail)))))))))
+(define (remove-comments tree)
+  (define (rem-com sx)
+    (match sx
+      ('() sx)
+      (`((@ (comment . ,_)) . ,tail) (rem-com tail))
+      (`((@ (comment . ,_) . ,rest) . ,tail) `((@ rest) . ,(rem-com tail)))
+      (`((comment . ,_) . ,tail) (rem-com tail))
+      ((head . tail) (cons (rem-com head) (rem-com tail)))
+      (atom atom)))
+  (rem-com tree))
 
 (define (remove-comments! sx0)
   (define (merge-tail pl tl)
